@@ -1,6 +1,6 @@
 package Fey::Test::Loader;
-BEGIN {
-  $Fey::Test::Loader::VERSION = '0.09';
+{
+  $Fey::Test::Loader::VERSION = '0.10';
 }
 
 use strict;
@@ -132,12 +132,16 @@ sub compare_columns {
             qw( type generic_type length precision
             is_nullable is_auto_increment )
             ) {
+
+            my $got = $col1->$meth();
             my $expect
                 = exists $override->{$fq_name}{$meth}
                 ? $override->{$fq_name}{$meth}
                 : $col2->$meth();
+
             is(
-                lc $col1->$meth(), lc $expect,
+                ( defined $got    ? lc $got    : undef ),
+                ( defined $expect ? lc $expect : undef ),
                 "schemas agree on $meth for $fq_name"
             );
         }
@@ -217,29 +221,3 @@ sub _fk_id {
 }
 
 1;
-
-__END__
-=pod
-
-=head1 NAME
-
-Fey::Test::Loader
-
-=head1 VERSION
-
-version 0.09
-
-=head1 AUTHOR
-
-Dave Rolsky <autarch@urth.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2010 by Dave Rolsky.
-
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
-
-=cut
-
