@@ -1,6 +1,6 @@
 package Fey::Test::mysql;
-BEGIN {
-  $Fey::Test::mysql::VERSION = '0.09';
+{
+  $Fey::Test::mysql::VERSION = '0.10';
 }
 
 use strict;
@@ -13,12 +13,6 @@ BEGIN {
     unless ( eval { require DBD::mysql; 1 } ) {
         plan skip_all => 'These tests require DBD::mysql';
     }
-
-    unless ( $ENV{RELEASE_TESTING} || $ENV{AUTHOR_TESTING} || -d '.hg' ) {
-        plan skip_all =>
-            'These tests are only run if either the RELEASE_TESTING or AUTHOR_TESTING'
-            . ' env var is true, or if being run from a Mercurial checkout dir.';
-    }
 }
 
 use DBI;
@@ -33,20 +27,26 @@ use File::Temp ();
 
         return $DBH if $DBH;
 
-        my $dbh = DBI->connect( 'dbi:mysql:', '', '',
-            { PrintError => 0, RaiseError => 1 } );
+        my $dbh = DBI->connect(
+            'dbi:mysql:', q{}, q{},
+            { PrintError => 0, RaiseError => 1 }
+        );
 
         $dbh->func( 'dropdb', 'test_Fey', 'admin' );
 
         # The dropdb command apparently disconnects the handle.
-        $dbh = DBI->connect( 'dbi:mysql:', '', '',
-            { PrintError => 0, RaiseError => 1 } );
+        $dbh = DBI->connect(
+            'dbi:mysql:', q{}, q{},
+            { PrintError => 0, RaiseError => 1 }
+        );
 
         $dbh->func( 'createdb', 'test_Fey', 'admin' )
             or die $dbh->errstr();
 
-        $dbh = DBI->connect( 'dbi:mysql:test_Fey', '', '',
-            { PrintError => 0, RaiseError => 1 } );
+        $dbh = DBI->connect(
+            'dbi:mysql:test_Fey', q{}, q{},
+            { PrintError => 0, RaiseError => 1 }
+        );
 
         $dbh->do('SET sql_mode = ANSI');
 
@@ -126,29 +126,3 @@ EOF
 }
 
 1;
-
-__END__
-=pod
-
-=head1 NAME
-
-Fey::Test::mysql
-
-=head1 VERSION
-
-version 0.09
-
-=head1 AUTHOR
-
-Dave Rolsky <autarch@urth.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2010 by Dave Rolsky.
-
-This is free software, licensed under:
-
-  The Artistic License 2.0 (GPL Compatible)
-
-=cut
-
